@@ -17,8 +17,8 @@ YELLOW ="\033[1m" #"\033[93m" # unreadable on white backgrounds
 CYAN   ="\033[96m"
 NORMAL ="\033[0m"
 
-# Returns the name of the shared object (i.e. libkdeui.so.4)
-# referenced by a libtool archive (like libkdeui.la)
+# Returns the name of the shared object (i.e. libtdeui.so.4)
+# referenced by a libtool archive (like libtdeui.la)
 def getSOfromLA(lafile):
         contents = open(lafile, 'r').read()
         match = re.search("^dlname='([^']*)'$", contents, re.M)
@@ -30,58 +30,58 @@ def exists(env):
 	return True
 
 def detect_kde(env):
-	""" Detect the qt and kde environment using kde-config mostly """
+	""" Detect the qt and kde environment using tde-config mostly """
 
 	prefix     = env['ARGS'].get('prefix', None)
 	execprefix = env['ARGS'].get('execprefix', None)
 	datadir    = env['ARGS'].get('datadir', None)
 	libdir     = env['ARGS'].get('libdir', None)
 	kdeincludes= env['ARGS'].get('kdeincludes', None)
-	kdelibs    = env['ARGS'].get('kdelibs', None)
+	tdelibs    = env['ARGS'].get('tdelibs', None)
 	qtincludes = env['ARGS'].get('qtincludes', None)
 	tqtincludes= env['ARGS'].get('tqtincludes', None)
 	qtlibs     = env['ARGS'].get('qtlibs', None)
-	kdedir     = env['ARGS'].get('kdedir', None)
+	tdedir     = env['ARGS'].get('tdedir', None)
 
-	## Detect the kde libraries
-	print "Checking for kde-config           : ",
-	str="which kde-config 2>/dev/null"
-	if kdedir: str="which %s 2>/dev/null" % (kdedir+'/bin/kde-config')
+	## Detect the tde libraries
+	print "Checking for tde-config           : ",
+	str="which tde-config 2>/dev/null"
+	if tdedir: str="which %s 2>/dev/null" % (tdedir+'/bin/tde-config')
 	kde_config = os.popen(str).read().strip()
 	if len(kde_config):
-		print GREEN + 'kde-config was found as ' + kde_config + NORMAL
+		print GREEN + 'tde-config was found as ' + kde_config + NORMAL
 	else:
-		if kdedir: print RED + 'kde-config was NOT found in the folder given ' + kdedir + NORMAL
-		else: print RED + 'kde-config was NOT found in your PATH' + NORMAL
+		if tdedir: print RED + 'tde-config was NOT found in the folder given ' + tdedir + NORMAL
+		else: print RED + 'tde-config was NOT found in your PATH' + NORMAL
 		print "Make sure kde is installed properly"
-		print "(missing package kdebase-devel?)"
+		print "(missing package tdebase-devel?)"
 		env.Exit(1)
-	if kdedir: env['KDEDIR']=kdedir
-	else: env['KDEDIR'] = os.popen(kde_config+' -prefix').read().strip()
+	if tdedir: env['TDEDIR']=tdedir
+	else: env['TDEDIR'] = os.popen(kde_config+' -prefix').read().strip()
 
-	print "Checking for kde version          : ",
-	kde_version = os.popen(kde_config+" --version|grep KDE").read().strip().split()[1]
-	kde_major = kde_version.split('.')[0].lstrip('R')
-	kde_minor = kde_version.split('.')[1]
-	kde_patch = kde_version.split('.')[2]
+	print "Checking for tde version          : ",
+	tde_version = os.popen(kde_config+" --version|grep TDE").read().strip().split()[1]
+	tde_major = tde_version.split('.')[0].lstrip('R')
+	tde_minor = tde_version.split('.')[1]
+	tde_patch = tde_version.split('.')[2]
 	try:
-		env['KDEm1']=int(kde_major)
+		env['KDEm1']=int(tde_major)
 	except:
 		pass
 	try:
-		env['KDEm2']=int(kde_minor)
+		env['KDEm2']=int(tde_minor)
 	except:
 		pass
 	try:
-		env['KDEm3']=int(kde_patch)
+		env['KDEm3']=int(tde_patch)
 	except:
 		pass
-	if int(kde_major) != 3 or int(kde_minor) < 2:
-		print RED + kde_version
-		print RED + "Your kde version might be too old" + NORMAL
-		print RED + "Please make sure TDE is at least 3.2" + NORMAL
+	if int(tde_major) != 14:
+		print RED + tde_version
+		print RED + "Your tde version might be too old" + NORMAL
+		print RED + "Please make sure TDE is at least R14.0" + NORMAL
 	else:
-		print GREEN + kde_version + NORMAL
+		print GREEN + tde_version + NORMAL
 
 	## Detect the qt library
 	print "Checking for the qt library       : ",
@@ -90,11 +90,11 @@ def detect_kde(env):
 		print GREEN + "qt is in " + qtdir + NORMAL
 	else:
 		libdir = os.popen(kde_config + ' --expandvars --install lib').read().strip()
-		libkdeuiSO = libdir+'/'+getSOfromLA(libdir+'/libkdeui.la')
+		libtdeuiSO = libdir+'/'+getSOfromLA(libdir+'/libtdeui.la')
 		try:
-			m = re.search('(.*)/lib/libqt.*', os.popen('ldd '+libkdeuiSO+' | grep libqt').read().strip().split()[2])
+			m = re.search('(.*)/lib/libqt.*', os.popen('ldd '+libtdeuiSO+' | grep libqt').read().strip().split()[2])
 		except:
-			m = re.search('(.*)/lib/libtqt.*', os.popen('ldd ' + libkdeuiSO + ' | grep libtqt').read().strip().split()[2])
+			m = re.search('(.*)/lib/libtqt.*', os.popen('ldd ' + libtdeuiSO + ' | grep libtqt').read().strip().split()[2])
 			pass
 		if m:
 			qtdir = m.group(1)
@@ -131,6 +131,9 @@ def detect_kde(env):
 		moc = os.popen("which moc 2>/dev/null").read().strip()
 		if len(moc):
 			print YELLOW+"moc was found as "+moc+NORMAL
+		elif os.path.isfile("/usr/share/tqt3/bin/moc"):
+			moc = "/usr/share/tqt3/bin/moc"
+			print YELLOW+"moc was found as "+moc+NORMAL
 		elif os.path.isfile("/usr/share/qt3/bin/moc"):
 			moc = "/usr/share/qt3/bin/moc"
 			print YELLOW+"moc was found as "+moc+NORMAL
@@ -145,7 +148,7 @@ def detect_kde(env):
 		# The user told where to look for and it looks valid
 		print GREEN + "ok " + tqtincludes + NORMAL
 	else:
-		if os.path.isfile(qtdir + "/include/tqlayout.h"):
+		if os.path.isfile(qtdir + "/include/qlayout.h"):
 			# Automatic detection
 			print GREEN + "ok " + qtdir + "/include/ " + NORMAL
 			tqtincludes = qtdir + "/include/"
@@ -163,33 +166,33 @@ def detect_kde(env):
 			
 	## check for the qt includes
 	print "Checking for the qt includes      : ",
-	if qtincludes and os.path.isfile(qtincludes + "/qglobal.h"):
+	if qtincludes and os.path.isfile(qtincludes + "/ntqglobal.h"):
 		# The user told where to look for and it looks valid
 		print GREEN + "ok " + qtincludes + NORMAL
 	else:
-		if os.path.isfile(qtdir + "/include/qglobal.h"):
+		if os.path.isfile(qtdir + "/include/ntqglobal.h"):
 			# Automatic detection
 			print GREEN + "ok " + qtdir + "/include/ " + NORMAL
 			qtincludes = qtdir + "/include/"
-		elif os.path.isfile("/usr/include/qt3/qglobal.h"):
+		elif os.path.isfile("/usr/include/tqt3/ntqglobal.h"):
 			# Debian probably
-			print YELLOW + "the qt headers were found in /usr/include/qt3/ " + NORMAL
-			qtincludes = "/usr/include/qt3"
+			print YELLOW + "the qt headers were found in /usr/include/tqt3/ " + NORMAL
+			qtincludes = "/usr/include/tqt3"
 		else:
 			print RED + "the qt headers were not found" + NORMAL
 			env.Exit(1)
 
-	print "Checking for the kde includes     : ",
+	print "Checking for the tde includes     : ",
 	kdeprefix = os.popen(kde_config + " --prefix").read().strip()
 	if not kdeincludes:
 		kdeincludes = kdeprefix+"/include/"
 	if os.path.isfile(kdeincludes + "/klineedit.h"):
 		print GREEN+"ok "+kdeincludes+NORMAL
 	else:
-		if os.path.isfile(kdeprefix+"/include/kde/klineedit.h"):
+		if os.path.isfile(kdeprefix+"/include/tde/klineedit.h"):
 			# Debian, Fedora probably
-			print YELLOW+"the kde headers were found in "+kdeprefix+"/include/kde/"+NORMAL
-			kdeincludes = kdeprefix + "/include/kde/"
+			print YELLOW+"the kde headers were found in "+kdeprefix+"/include/tde/"+NORMAL
+			kdeincludes = kdeprefix + "/include/tde/"
 		else:
 			print RED+"The kde includes were NOT found"+NORMAL
 			env.Exit(1)
@@ -236,9 +239,9 @@ def detect_kde(env):
 
 	## kde libs and includes
 	env['KDEINCLUDEPATH']= kdeincludes
-	if not kdelibs:
-		kdelibs = os.popen(kde_config + ' --expandvars --install lib').read().strip()
-	env['KDELIBPATH']= kdelibs
+	if not tdelibs:
+		tdelibs = os.popen(kde_config + ' --expandvars --install lib').read().strip()
+	env['KDELIBPATH']= tdelibs
 
 	## qt libs and includes
 	env['QTINCLUDEPATH']= qtincludes
@@ -295,10 +298,10 @@ def generate(env):
 """+BOLD+"""* execprefix """+NORMAL+""": install path for binaries, ie: /usr/bin
 """+BOLD+"""* datadir    """+NORMAL+""": install path for the data, ie: /usr/local/share
 """+BOLD+"""* libdir     """+NORMAL+""": install path for the libs, ie: /usr/lib
-"""+BOLD+"""* kdedir     """+NORMAL+""": path to TDE directory,     ie: /opt/trinity
-"""+BOLD+"""* kdeincludes"""+NORMAL+""": path to the kde includes (/usr/include/kde on debian, ...)
+"""+BOLD+"""* tdedir     """+NORMAL+""": path to TDE directory,     ie: /opt/trinity
+"""+BOLD+"""* kdeincludes"""+NORMAL+""": path to the kde includes (/usr/include/tde on debian, ...)
 """+BOLD+"""* qtincludes """+NORMAL+""": same punishment, for qt includes (/usr/include/qt on debian, ...)
-"""+BOLD+"""* kdelibs    """+NORMAL+""": path to the kde libs, for linking the programs
+"""+BOLD+"""* tdelibs    """+NORMAL+""": path to the kde libs, for linking the programs
 """+BOLD+"""* qtlibs     """+NORMAL+""": same punishment, for qt libraries
 ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
 """+NORMAL)
@@ -319,7 +322,7 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
 		( 'QT_UIC', 'moc directory'),
 		( 'QT_MOC', 'moc executable command'),
 		( 'QTPLUGINS', 'uic executable command'),
-		( 'KDEDIR', 'root of kde directory' ),
+		( 'TDEDIR', 'root of kde directory' ),
 		( 'KDELIBPATH', 'path to the kde libs' ),
 		( 'KDEINCLUDEPATH', 'path to the kde includes' ),
 
@@ -341,7 +344,7 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
 	opts.Update(env)
 
 	# reconfigure when things are missing
-	if 'configure' in env['TARGS'] or not env.has_key('QTDIR') or not env.has_key('KDEDIR'):
+	if 'configure' in env['TARGS'] or not env.has_key('QTDIR') or not env.has_key('TDEDIR'):
 		detect_kde(env)
 
 	# finally save the configuration
@@ -379,7 +382,7 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
 		act=[]
 		act.append('$QT_UIC $QT_UIC_HFLAGS -o '+target[0].path+' '+source[0].path)
 		act.append('rm -f '                           +target[1].path)
-		act.append('echo \'#include <klocale.h>\' >> '+target[1].path)
+		act.append('echo \'#include <tdelocale.h>\' >> '+target[1].path)
 		act.append('echo \'#include <kdialog.h>\' >> '+target[1].path)
 		act.append('$QT_UIC $QT_UIC_CFLAGS -impl '+target[0].path+' -o '+target[1].path+'.tmp '+source[0].path)
 		act.append('cat '+target[1].path+'.tmp >> '+target[1].path)
@@ -427,7 +430,7 @@ ie: """+BOLD+"""scons configure libdir=/usr/local/lib qtincludes=/usr/include/qt
 	###### kcfg file processing
 	def kcfgGenerator(target, source, env, for_signature):
 		act=[]
-		act.append('kconfig_compiler -d'+str(source[0].get_dir())+' '+source[1].path+' '+source[0].path)
+		act.append('tdeconfig_compiler -d'+str(source[0].get_dir())+' '+source[1].path+' '+source[0].path)
 		return act
 	
 	def kcfgEmitter(target, source, env):
